import request from "@/scripts/httpRequest";

/**
 * @description 同步库列表
 * @param { string } isSync  是否同步库 1 同步库 2本地库 qita 全部库
 */
export const getSyncTables = (query: any) => {
  return request({
    url: "/data/api-v/dbtable/queryDbTables/1",
    method: "post",
    data: query
  });
};

/**
 * @description 本地库列表
 * @param { int } isSync  是否同步库 1 同步库 2本地库 qita 全部库
 */
export const getLocalTables = (query: any) => {
  return request({
    url: "/data/api-v/dbtable/queryDbTables/2",
    method: "post",
    data: query
  });
};

/**
 * @description 添加底库
 * @param { string } isSync    是否同步库 1 同步库 2本地库 qita 全部库
 * @param { string } bwType    黑白名单  黑名单:1,白名单:0
 * @param { string } enabled   0为生效 1为失效
 * @param { string } tableName 底库名称
 * @param { string } startTime 开始时间
 * @param { string } endTime   结束时间 传''为永久
 * @param { string } tableType 底库类型
 */
export const addBase = (query: any) => {
  return request({
    url: "/data/api-v/dbtable/addDbTableInfo",
    method: "put",
    data: query
  });
};

/**
 * @description 修改底库
 * @param { string } isSync    是否同步库 1 同步库 2本地库 qita 全部库
 * @param { string } bwType    黑白名单  黑名单:1,白名单:0
 * @param { string } enabled   0为生效 1为失效
 * @param { string } tableName 底库名称
 * @param { string } startTime 开始时间
 * @param { string } endTime   结束时间 传''为永久
 * @param { string } tableType 底库类型
 */
export const updateBase = (query: any) => {
  return request({
    url: "/data/api-v/dbtable/updateDbTables",
    method: "post",
    data: query
  });
};

/**
 * 更改底库状态
 * @param {string} id
 * @param {string} enable   0为生效 1为失效
 */
export const updateDbTableStatus = (query: any) => {
  return request({
    url: "/data/api-v/dbtable/updateDbTableStatus",
    method: "post",
    data: query
  });
};

/**
 * @description 人员列表
 * @param { string } tableId
 * @param { string } orderName  排序字段
 * @param { string } orderType  排序规则 desc
 * @param { string } contentValue  搜索框内容
 * @param { string } page  分页 第几页
 * @param { string } size  分页 每页多少条
 */
export const getPersonList = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/queryDbPersonsByTbId",
    method: "post",
    data: query
  });
};

/**
 * @description 以图搜图人员列表
 * @param { string } tableId
 * @param { string } orderName  排序字段
 * @param { string } orderType  排序规则 desc
 * @param { string } faceUrl    图片路径
 * @param { string } threshold  阈值
 * @param { string } page       分页 第几页
 * @param { string } size       分页 每页多少条
 */
export const getPersonListByPhoto = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/queryDbPersonsByCampare/",
    method: "post",
    data: query
  });
};

/**
 * @description 批量删除
 * @param { string } uuids         id数组
 */
export const deleteBasePersons = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/deleteMoreDbPerson",
    method: "post",
    data: query
  });
};

/**
 * @description 修改底库人员
 * @param { string } uuid         id
 * @param { string } age          年龄
 * @param { string } idcard       身份证号
 * @param { string } enabled      0为生效 1为失效
 * @param { string } monitorLevel 等级 
 * @param { string } tableId      库id
 * @param { string } phoneNum     手机号码
 * @param { string } personName   人员姓名
 * @param { string } sex          性别
 */
export const updateBasePerson = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/updateDbPerson",
    method: "post",
    data: query
  });
};

/**
 * @description 底库的以图搜图
 * @param { string } databases        底库ids
 * @param { string } picUrl           url
 * @param { string } size             身份证号
 * @param { string } page             0为生效 1为失效
 * @param { string } threshold        阈值
 */
export const searchFromBase = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/queryDbPersonsByCompare",
    method: "post",
    data: query
  });
};

// 底库页面标签查询
export const getTagList = (query: any) => {
  return request({
    url: "/data/api-v/es/tagList",
    method: "post",
    data: query
  });
};

// 复制
export const copy = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/copy",
    method: "post",
    data: query
  });
};

// 移动
export const move = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/move",
    method: "post",
    data: query
  });
};

// 批量上传车牌
export const plateBatch = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/multiUploadCarNo",
    method: "post",
    data: query
  })
}

/**
 * @description 新增车辆
 * @param { string } uuid         id
 * @param { string } age          年龄
 * @param { string } idcard       身份证号
 * @param { string } enabled      0为生效 1为失效
 * @param { string } monitorLevel 等级 
 * @param { string } tableId      库id
 * @param { string } phoneNum     手机号码
 * @param { string } personName   人员姓名
 * @param { string } sex          性别
 * @param { string } carBrand     0
 * @param { string } carColor     0
 * @param { string } carNo        车牌号
 * @param { string } carPicUrls   车辆照片
 */
export const addBaseCar = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/addDbPerson",
    method: "put",
    data: query
  });
};

/**
 * @description 修改车辆信息
 * @param { string } uuid         id
 * @param { string } age          年龄
 * @param { string } idcard       身份证号
 * @param { string } enabled      0为生效 1为失效
 * @param { string } monitorLevel 等级 
 * @param { string } tableId      库id
 * @param { string } phoneNum     手机号码
 * @param { string } personName   人员姓名
 * @param { string } sex          性别
 * @param { string } carBrand     0
 * @param { string } carColor     0
 * @param { string } carNo        车牌号
 * @param { string } carPicUrls   车辆照片
 */
export const updateBaseCar = (query: any) => {
  return request({
    url: "/data/api-v/dbperson/updateDbPerson",
    method: "post",
    data: query
  });
};